from setuptools import setup

setup(name='packagemaketest',
      version='0.6',
      description='The funniest joke in Japan',
      url='http://github.com/xinkent/packagemaketest.git',
      author='K Xin',
      author_email='xinkent1994@gmail.com',
      license='MIT',
      packages=['packagemaketest'],
      zip_safe=False)
